searchData={"items":[{"type":"module","title":"Fortune","doc":"Get a fortune!\n\nFortune reads a string, usually a random one, from one or more fortune files.\nFortune files contain a list of strings and an associated index for for quick\nretrieval of a randomly chosen string. This implementation provides an Elixir\ntake on the ubiquitous Unix fortune implementation. It is compatible with\nUnix fortune and can read most Unix fortune files.\n\n```elixir\niex> Fortune.random()\n{:ok, \"Harness the power of the BEAM, one Elixir potion at a time.\"}\n```\n\nNo fortunes are provided, though. You'll need to add your own, add Elixir\nlibraries to your mix dependencies that have fortunes, or use your system's fortunes.\n\nFortunes provided by Elixir libraries are stored in that library's\n`priv/fortune` directory. See the `README.md` for using the `:fortune_compiler`\nfor adding your own.\n\nIf no Elixir-provided fortunes are found, `fortune` checks the system's\n`/usr/share/games/fortune` directory (and various similar ones)  for fortunes\nto find something.\n\nSee `fortune_options/0` for modifying fortune search paths.","ref":"Fortune.html"},{"type":"function","title":"Fortune.random/1","doc":"Return a random fortune","ref":"Fortune.html#random/1"},{"type":"function","title":"Fortune.random!/1","doc":"Raising version of random/1","ref":"Fortune.html#random!/1"},{"type":"type","title":"Fortune.fortune_options/0","doc":"Fortune options\n\nPass these to `Fortune.random/1` and similar functions:\n\n* `:paths` - a list of absolute paths to `fortune` directories or files. Overrides other options\n* `:included_applications` - specifically include these applications that contain fortunes\n* `:excluded_applications` - exclude these applications from being scanned for fortunes\n* `:include_system_fortunes?` - set to `true` to include system fortunes. Defaults to `true` if no Elixir projects supply fortunes.\n\nTo set defaults for your project, add Fortune options to your application's `config.exs`:\n\n```elixir\nconfig :fortune, include_system_fortunes?: true\n```","ref":"Fortune.html#t:fortune_options/0"},{"type":"task","title":"mix compile.fortune_compiler","doc":"Compile fortune files\n\nThis compiler parses specially formatted files, indexes them, and saves the results\nto the `priv/fortune` directory. To be precise, this does what the Unix `strfile`\ncommand does.\n\nBy default, input files should be placed in the `fortune` directory in a project.\nEach fortune (aka string) is separated by a `%` line like the following:\n\n```text\nMy first fortune\n%\nAnother string or fortune\nand this can be multiple lines too.\n%\nThe last string\n```\n\n# Configuration\n\n* `:fortunec_paths` - directories to find fortune files. Defaults to `[\"fortune\"]`","ref":"Mix.Tasks.Compile.FortuneCompiler.html"},{"type":"extras","title":"Fortune","doc":"# Fortune\n\n[![Hex version](https://img.shields.io/hexpm/v/fortune.svg \"Hex version\")](https://hex.pm/packages/fortune)\n[![API docs](https://img.shields.io/hexpm/v/fortune.svg?label=hexdocs \"API docs\")](https://hexdocs.pm/fortune/)\n[![CircleCI](https://circleci.com/gh/fhunleth/elixir-fortune.svg?style=svg)](https://circleci.com/gh/fhunleth/elixir-fortune)\n\nGet a fortune!\n\nFortune reads a string, usually a random one, from one or more fortune files.\nFortune files contain a list of strings and an associated index for for quick\nretrieval of a randomly chosen string. This implementation provides an Elixir\ntake on the ubiquitous [Unix fortune](https://en.wikipedia.org/wiki/Fortune_(Unix))\nimplementation. It is compatible with Unix fortune and can read most Unix\nfortune files.\n\n```elixir\niex> Fortune.random()\n{:ok, \"Harness the power of the BEAM, one Elixir potion at a time.\"}\n```\n\nNo fortunes are provided, though. You'll need to add your own, add Elixir\nlibraries to your mix dependencies that have fortunes, or configure Fortune to\nuse your system ones.\n\nHere's an example on Mac when you've installed `fortune` via Homebrew:\n\n```elixir\nFortune.random(include_system_fortunes?: true)\n```\n\nFortunes provided by Elixir libraries are stored in that library's\n`priv/fortune` directory when using this library's `fortune` compiler. Fortune\nscans for these paths by default.","ref":"readme.html"},{"type":"extras","title":"Installation - Fortune","doc":"Add `fortune` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:fortune, \"~> 0.1\"}\n  ]\nend\n```\n\nNote that Fortune does NOT provide any fortunes itself.","ref":"readme.html#installation"},{"type":"extras","title":"Configuration - Fortune","doc":"The defaults should be good for most users. If not, see `fortune_options/0` to adjust fortune search paths and more. These can be passed to `Fortune.random/1` or added to your `config.exs` for use as new defaults:\n\n```elixir\n# Completely override fortune search paths\nconfig :fortune, paths: [Path.join([\"some/location\", \"fortune\"])]]\n\n# Only include fortunes from a couple applications\nconfig :fortune, included_applications: [:funny_app, :helpful_app]\n\n# Remove fortunes from a list of applications\nconfig :fortune, excluded_applications: [:bad_app]\n```","ref":"readme.html#configuration"},{"type":"extras","title":"Adding fortunes to your Elixir project - Fortune","doc":"Any project can supply fortunes (or tips, since that's the likely use case).\n\nHere are the steps:\n\n1. Create a `fortune` directory in your Elixir project\n1. Create one or more fortune-formatted files in the `fortune` directory\n1. Add the `:fortune_compiler` to the compilers list in your `mix.exs`\n1. Run `mix compile`\n\n#","ref":"readme.html#adding-fortunes-to-your-elixir-project"},{"type":"extras","title":"Fortune files - Fortune","doc":"Fortune files are text files with quotes separated by `%` lines. Filenames can\nbe anything but must not have an extension.\n\nIt's easies to see by example:\n\n```sh\ncd path/to/my/project\nmkdir -p fortune\ntouch fortune/my-fortunes\n```\n\nThen open `my-fortunes` in a text editor:\n\n```text\nMy first fortune\n%\nAnother string or fortune\nand this can be multiple lines too.\n%\nThe last string\n```\n\n#","ref":"readme.html#fortune-files"},{"type":"extras","title":"Compiling fortune files - Fortune","doc":"Fortune files need to be indexed for use by `fortune`. The `:fortune_compiler`\nknows how to do this, so add it to your `mix.exs`:\n\n```elixir\n  def project do\n    [\n      ...\n      compilers: Mix.compilers() ++ [:fortune_compiler],\n      ...\n    ]\n  end\n```\n\nIf you don't like putting your fortunes in the `fortune` directory, use the\n`:fortunec_paths` option.\n\nFinally, run:\n\n```sh\nmix deps.get\nmix compile\n```\n\nThen to see the result of your work, run:\n\n```sh\niex -S mix\n\nInteractive Elixir - press Ctrl+C to exit (type h() ENTER for help)\niex(1)> Fortune.random()\n{:ok, \"My first fortune\"}\n```","ref":"readme.html#compiling-fortune-files"},{"type":"extras","title":"Changelog","doc":"# Changelog","ref":"changelog.html"},{"type":"extras","title":"v0.1.0 - Changelog","doc":"Initial release to hex.","ref":"changelog.html#v0-1-0"}],"content_type":"text/markdown"}